==> mingw-w64-thorvg-0.13.7-1.src.tar.zst: thorvg-0.13.7/examples/GifSaver.cpp <==
/*
 * Copyright (c) 2023 - 2024 the ThorVG project. All rights reserved.

 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:

 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.

 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#include <iostream>
#include <thread>
#include <thorvg.h>

using namespace std;

void exportGif()
{
    auto animation = tvg::Animation::gen();
    auto picture = animation->picture();
    if (picture->load(EXAMPLE_DIR"/lottie/walker.json") != tvg::Result::Success) {
        cout << "Lottie is not supported. Did you enable Lottie Loader?" << endl;
        return;
    }

    picture->size(800, 800);

    auto saver = tvg::Saver::gen();
    if (saver->save(std::move(animation), "./test.gif") != tvg::Result::Success) {
        cout << "Problem with saving the json file. Did you enable Gif Saver?" << endl;
        return;
    }
    saver->sync();
    cout << "Successfully exported to test.gif." << endl;
}


/************************************************************************/
/* Main Code                                                            */
/************************************************************************/

int main(int argc, char **argv)
{
    //Initialize ThorVG Engine
    if (tvg::Initializer::init(tvg::CanvasEngine::Sw, 0) == tvg::Result::Success) {

        exportGif();

        //Terminate ThorVG Engine
        tvg::Initializer::term(tvg::CanvasEngine::Sw);

    } else {
        cout << "engine is not supported" << endl;
    }
    return 0;
}

==> mingw-w64-thorvg-0.15.16-1.src.tar.zst: thorvg-0.15.16/examples/GifSaver.cpp <==
/*
 * Copyright (c) 2023 - 2024 the ThorVG project. All rights reserved.

 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:

 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.

 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#include "Example.h"

using namespace std;

/************************************************************************/
/* ThorVG Saving Contents                                               */
/************************************************************************/


void exportGif()
{
    auto animation = tvg::Animation::gen();
    auto picture = animation->picture();
    if (!tvgexam::verify(picture->load(EXAMPLE_DIR"/lottie/walker.json"))) return;

    picture->size(800, 800);

    auto saver = tvg::Saver::gen();
    if (!tvgexam::verify(saver->save(std::move(animation), "./test.gif"))) return;
    saver->sync();

    cout << "Successfully exported to test.gif." << endl;
}


/************************************************************************/
/* Entry Point                                                          */
/************************************************************************/

int main(int argc, char **argv)
{
    if (tvgexam::verify(tvg::Initializer::init(tvg::CanvasEngine::Sw, 0))) {

        exportGif();

        tvg::Initializer::term(tvg::CanvasEngine::Sw);
    }
    return 0;
}
